
#ifndef VTKPVADAPTORSPARTICLE_EXPORT_H
#define VTKPVADAPTORSPARTICLE_EXPORT_H

#ifdef VTKPVADAPTORSPARTICLE_STATIC_DEFINE
#  define VTKPVADAPTORSPARTICLE_EXPORT
#  define VTKPVADAPTORSPARTICLE_NO_EXPORT
#else
#  ifndef VTKPVADAPTORSPARTICLE_EXPORT
#    ifdef AdaptorsParticle_EXPORTS
        /* We are building this library */
#      define VTKPVADAPTORSPARTICLE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVADAPTORSPARTICLE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVADAPTORSPARTICLE_NO_EXPORT
#    define VTKPVADAPTORSPARTICLE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVADAPTORSPARTICLE_DEPRECATED
#  define VTKPVADAPTORSPARTICLE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVADAPTORSPARTICLE_DEPRECATED_EXPORT
#  define VTKPVADAPTORSPARTICLE_DEPRECATED_EXPORT VTKPVADAPTORSPARTICLE_EXPORT VTKPVADAPTORSPARTICLE_DEPRECATED
#endif

#ifndef VTKPVADAPTORSPARTICLE_DEPRECATED_NO_EXPORT
#  define VTKPVADAPTORSPARTICLE_DEPRECATED_NO_EXPORT VTKPVADAPTORSPARTICLE_NO_EXPORT VTKPVADAPTORSPARTICLE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVADAPTORSPARTICLE_NO_DEPRECATED
#    define VTKPVADAPTORSPARTICLE_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVAdaptorsParticleModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVADAPTORSPARTICLE_EXPORT_H */
